Lexing Module
Types
| Type | Description |
|
The type of tables for an ascii lexer generated by fslex. |
|
|
Input buffers consumed by lexers generated by |
|
|
Position information stored for lexing tokens |
|
|
The type of tables for an unicode lexer generated by fslex. |
Functions and values
| Function or value |
Description
|
Full Usage:
UnicodeFileAsLexbuf (arg1, arg1)
Parameters: Returns: FileStream * StreamReader * LexBuffer<char>
|
Standard utility to create a Unicode LexBuffer One small annoyance is that LexBuffers are not IDisposable. This means we can't just return the LexBuffer object, since the file it wraps wouldn't get closed when we're finished with the LexBuffer. Hence we return the stream, the reader and the LexBuffer. The caller should dispose the first two when done.
|
FsLexYacc