LexBuffer<'char> Type
Input buffers consumed by lexers generated by
Instance members
| Instance member |
Description
|
|
Dynamically typed, non-lexically scoped parameter table
|
Full Usage:
this.DiscardInput
|
Remove all input, though don't discard the current lexeme |
|
The end position for the lexeme
|
|
True if the refill of the buffer ever failed , or if explicitly set to true.
|
|
The matched string
|
Full Usage:
this.LexemeChar
Parameters:
int
Returns: 'char
|
Fetch a particular character in the matched string
|
Full Usage:
this.LexemeLength
Returns: int
|
The length of the matched string
|
|
The start position for the lexeme
|
Static members
| Static member |
Description
|
|
|
Full Usage:
LexBuffer.FromBinaryReader(arg1)
Parameters:
BinaryReader
Returns: LexBuffer<byte>
|
Create a lex buffer suitable for use with ASCII byte lexing that reads byte inputs from the given binary reader
|
|
|
|
|
|
|
|
|
|
Create a lex buffer suitable for use with a Unicode lexer that reads character inputs from the given text reader
|
|
FsLexYacc