Position Type
Position information stored for lexing tokens
Record fields
| Record Field |
Description
|
Full Usage:
pos_bol
Field type: int
|
The absolute offset of the beginning of the line
|
Full Usage:
pos_cnum
Field type: int
|
The absolute offset of the column for the position
|
The file name for the position
|
|
Full Usage:
pos_lnum
Field type: int
|
The line number for the position
|
Full Usage:
pos_orig_lnum
Field type: int
|
The line number for the position in the original source file
|
Instance members
| Instance member |
Description
|
Full Usage:
this.AbsoluteOffset
Returns: int
|
The character number in the input stream
|
Full Usage:
this.Column
Returns: int
|
Return the column number marked by the position, i.e. the difference between the AbsoluteOffset and the StartOfLineAbsoluteOffset
|
|
Given a position at the start of a token of length n, return a position just beyond the end of the token
|
|
The file name associated with the input stream.
|
Full Usage:
this.Line
Returns: int
|
The line number in the input stream, assuming fresh positions have been updated using AsNewLinePos() and by modifying the EndPos property of the LexBuffer.
|
|
|
Full Usage:
this.OriginalLine
Returns: int
|
The line number for the position in the input stream, assuming fresh positions have been updated using AsNewLinePos()
|
|
|
Full Usage:
this.StartOfLineAbsoluteOffset
Returns: int
|
Return absolute offset of the start of the line marked by the position
|
Static members
| Static member |
Description
|
|
Get an arbitrary position, with the empty string as filename, and
|
|
FsLexYacc