Logo FsLexYacc

UnicodeTables Type

The type of tables for an unicode lexer generated by fslex.

Instance members

Instance member Description

this.Interpret

Full Usage: this.Interpret

Parameters:
Returns: int

Interpret tables for a unicode lexer generated by fslex.

initialState : int
arg1 : LexBuffer<char>
Returns: int

Static members

Static member Description

UnicodeTables.Create(arg1, arg1)

Full Usage: UnicodeTables.Create(arg1, arg1)

Parameters:
Returns: UnicodeTables
arg0 : uint16 array array
arg1 : uint16 array
Returns: UnicodeTables

Type something to start searching.