ParseErrorContext<'tok> Type
The context provided when a parse error occurs
Instance members
| Instance member |
Description
|
|
The token that caused the parse error
|
|
The message associated with the parse error
|
|
The state active at the parse error
|
|
The tokens that would cause a reduction at the parse error
|
|
|
|
The token that would cause a shift at the parse error
|
|
The stack of state indexes active at the parse error
|
FsLexYacc