Logo FsLexYacc

Tables<'tok> Type

Tables generated by fsyacc The type of the tables contained in a file produced by the fsyacc.exe parser generator.

Record fields

Record Field Description

actionTableElements

Full Usage: actionTableElements

Field type: uint16 array

The sparse action table elements

Field type: uint16 array

actionTableRowOffsets

Full Usage: actionTableRowOffsets

Field type: uint16 array

The sparse action table row offsets

Field type: uint16 array

dataOfToken

Full Usage: dataOfToken

Field type: 'tok -> obj

A function to compute the data carried by a token

Field type: 'tok -> obj

endOfInputTag

Full Usage: endOfInputTag

Field type: int

The token number indicating the end of input

Field type: int

gotos

Full Usage: gotos

Field type: uint16 array

The sparse goto table

Field type: uint16 array

immediateActions

Full Usage: immediateActions

Field type: uint16 array

The immediate action table

Field type: uint16 array

numTerminals

Full Usage: numTerminals

Field type: int

The total number of terminals

Field type: int

parseError

Full Usage: parseError

Field type: ParseErrorContext<'tok> -> unit

This function is used to hold the user specified "parse_error" or "parse_error_rich" functions

Field type: ParseErrorContext<'tok> -> unit

productionToNonTerminalTable

Full Usage: productionToNonTerminalTable

Field type: uint16 array

This table is logically part of the Goto table

Field type: uint16 array

reductionSymbolCounts

Full Usage: reductionSymbolCounts

Field type: uint16 array

The number of symbols for each reduction

Field type: uint16 array

reductions

Full Usage: reductions

Field type: (IParseState -> obj) array

The reduction table

Field type: (IParseState -> obj) array

sparseGotoTableRowOffsets

Full Usage: sparseGotoTableRowOffsets

Field type: uint16 array

The sparse goto table row offsets

Field type: uint16 array

stateToProdIdxsTableElements

Full Usage: stateToProdIdxsTableElements

Field type: uint16 array

The sparse table for the productions active for each state

Field type: uint16 array

stateToProdIdxsTableRowOffsets

Full Usage: stateToProdIdxsTableRowOffsets

Field type: uint16 array

The sparse table offsets for the productions active for each state

Field type: uint16 array

tagOfErrorTerminal

Full Usage: tagOfErrorTerminal

Field type: int

The tag of the error terminal

Field type: int

tagOfToken

Full Usage: tagOfToken

Field type: 'tok -> int

A function to compute the tag of a token

Field type: 'tok -> int

Instance members

Instance member Description

this.Interpret

Full Usage: this.Interpret

Parameters:
    lexer : LexBuffer<'char> -> 'tok
    lexbuf : LexBuffer<'char>
    startState : int
    assocTableCacheInitialCapacity : int

Returns: obj

As Interpret, but with an explicit initial capacity for the per-parse AssocTable lookup caches (issue #54); 0 grows them on demand. Overrides ParseSettings.AssocTableCacheInitialCapacity for this parser. fsyacc emits a call to this overload when --assoc-cache-capacity is passed.

lexer : LexBuffer<'char> -> 'tok
lexbuf : LexBuffer<'char>
startState : int
assocTableCacheInitialCapacity : int
Returns: obj

this.Interpret

Full Usage: this.Interpret

Parameters:
Returns: obj

Interpret the parser table taking input from the given lexer, using the given lex buffer, and the given start state. Returns an object indicating the final synthesized value for the parse.

lexer : LexBuffer<'char> -> 'tok
lexbuf : LexBuffer<'char>
startState : int
Returns: obj

Type something to start searching.