AST Module
Types
| Type | Description |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Capture the name of the argument inside a rule. When the rule is typed, the type name is expected to have a single identifier. This is a known limitation and the caller can get around this by using a type alias. |
|
|
|
Functions and values
| Function or value |
Description
|
Full Usage:
AddToMultiMap trDict a b
Parameters:
MultiMap<'a, 'b>
a : 'a
b : 'b
Type parameters: 'a, 'b |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
NfaToDfa nfaNodeMap nfaStartNode
Parameters:
NfaNodeMap
nfaStartNode : NfaNode
Returns: DfaNode * DfaNode list
|
|
|
|
Full Usage:
NumUnicodeCategories
Returns: int
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
numLowUnicodeChars
Returns: int
|
|
|
|
|
|
|
|
Active patterns
| Active pattern |
Description
|
|
|
FsLexYacc