Logo FsLexYacc

RuleArgument Type

Capture the name of the argument inside a rule. When the rule is typed, the type name is expected to have a single identifier. This is a known limitation and the caller can get around this by using a type alias.

Union cases

Union case Description

Ident name

Full Usage: Ident name

Parameters:
name : Ident

Typed(name, typeName)

Full Usage: Typed(name, typeName)

Parameters:
name : Ident
typeName : Ident

Instance members

Instance member Description

this.IsIdent

Full Usage: this.IsIdent

Returns: bool
Returns: bool

this.IsTyped

Full Usage: this.IsTyped

Returns: bool
Returns: bool

Type something to start searching.